@@ -1,7 +1,7 @@
 """
 Type annotations for networkmanager service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/literals/)
 
 Usage::
 
@@ -66,7 +66,9 @@ __all__ = (
     "TransitGatewayConnectPeerAssociationStateType",
     "TransitGatewayRegistrationStateType",
     "TunnelProtocolType",
+    "NetworkManagerServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -158,6 +160,7 @@ TransitGatewayRegistrationStateType = Literal[
     "AVAILABLE", "DELETED", "DELETING", "FAILED", "PENDING"
 ]
 TunnelProtocolType = Literal["GRE"]
+NetworkManagerServiceName = Literal["networkmanager"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -189,6 +192,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -275,6 +279,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -311,6 +316,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -459,6 +465,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_global_networks",
     "get_connect_peer_associations",
